@@ -1,4 +1,5 @@
-from typing import Optional, List
+import textwrap
+from typing import Optional, List, Dict, Callable, Any
 
 import frontmatter
 import json
@@ -9,7 +10,7 @@ from frontmatter import u
 from yaml.parser import ParserError
 
 from sigla.lib.Nodes.Node import Node
-from sigla.lib.Nodes.template.engines.njk import njk
+from sigla.lib.Nodes.template.engines.jinja import jinja
 from sigla.lib.helpers.Context import Context
 from sigla.lib.helpers.files import ensure_parent_dir, ensure_file
 
@@ -66,26 +67,28 @@ There should be an error on the following yaml (frontmatter)
 
 
 def get_default_template_content(context):
-    def default_njk_template(dumped_context):
-        return f"""
----
-some_var: some_value
----
+    def default_jinja_template(dumped_context):
+        return textwrap.dedent(
+            f"""
+            ---
+            some_var: some_value
+            ---
 
-Available vars: {dumped_context}
+            Available vars: {dumped_context}
 
-Handle children:
+            Handle children:
 
-{{{{ render(children) }}}}
+            {{{{ render(children) }}}}
 
-{{% for child in children %}}
-    {{{{ render(child) }}}}
-{{% endfor %}}
-    
-    """
+            {{% for child in children %}}
+                {{{{ render(child) }}}}
+            {{% endfor %}}
+
+            """
+        )
 
     json_context = json.dumps(list(context.keys()) + ["children"])
-    return default_njk_template(json_context)
+    return default_jinja_template(json_context)
 
 
 class NodeTemplate(Node):
@@ -93,7 +96,7 @@ class NodeTemplate(Node):
     kind = "template"
     templates_directory = "./.sigla/templates"
     create_missing_templates = True
-    filters = {}
+    filters: Dict[str, Callable[[Any], Any]] = {}
 
     def __init__(
         self,
@@ -111,7 +114,7 @@ class NodeTemplate(Node):
     def template_name(self):
         name = self.get_template_name()
         name = name.replace("-", "/")
-        name = f"{name}.njk"
+        name = f"{name}.jinja2"
         return name
 
     @property
@@ -190,13 +193,16 @@ class NodeTemplate(Node):
 
         context = ctx.get_context()
 
-        result = njk(
+        data = {}
+        data.update(context)
+        data.update(kwargs)
+
+        result = jinja(
             template,
-            **context,
+            **data,
             filters=self.filters,
             ctx=context,
             children=self.children,
-            **kwargs,
         )
 
         return result
